aboutsummaryrefslogtreecommitdiff
path: root/build.zig
diff options
context:
space:
mode:
Diffstat (limited to 'build.zig')
-rw-r--r--build.zig10
1 files changed, 5 insertions, 5 deletions
diff --git a/build.zig b/build.zig
index 05f6350..53ede62 100644
--- a/build.zig
+++ b/build.zig
@@ -28,7 +28,7 @@ pub fn build(b: *std.Build) void {
// to our consumers. We must give it a name because a Zig package can expose
// multiple modules and consumers will need to be able to specify which
// module they want to access.
- const mod = b.addModule("storyboard", .{
+ const mod = b.addModule("memora", .{
// The root source file is the "entry point" of this module. Users of
// this module will only be able to access public declarations contained
// in this file, which means that if you have declarations that you
@@ -58,7 +58,7 @@ pub fn build(b: *std.Build) void {
// If neither case applies to you, feel free to delete the declaration you
// don't need and to put everything under a single module.
const exe = b.addExecutable(.{
- .name = "storyboard",
+ .name = "memora",
.root_module = b.createModule(.{
// b.createModule defines a new module just like b.addModule but,
// unlike b.addModule, it does not expose the module to consumers of
@@ -73,12 +73,12 @@ pub fn build(b: *std.Build) void {
// List of modules available for import in source files part of the
// root module.
.imports = &.{
// Here "storyboard" is the name you will use in your source code to
// import this module (e.g. `@import("storyboard")`). The name is
// repeated because you are allowed to rename your imports, which
// can be extremely useful in case of collisions (which can happen
// importing modules from different packages).
- .{ .name = "storyboard", .module = mod },
+ .{ .name = "memora", .module = mod },
},
}),
});
@@ -73,12 +73,12 @@ pub fn build(b: *std.Build) void {
// root module.
.imports = &.{
- // Here "storyboard" is the name you will use in your source code to
- // import this module (e.g. `@import("storyboard")`). The name is
+ // Here "memora" is the name you will use in your source code to
+ // import this module (e.g. `@import("memora")`). The name is
// repeated because you are allowed to rename your imports, which
// can be extremely useful in case of collisions (which can happen